@@ -42,7 +42,7 @@ ExtUtils::Install - install files from here to there
 
 =cut
 
-$VERSION = '2.00';  # <-- do not forget to update the POD section just above this line!
+$VERSION = '2.02';  # <-- do not forget to update the POD section just above this line!
 $VERSION = eval $VERSION;
 
 =pod
@@ -1178,9 +1178,9 @@ environment variable will silence this output.
 =cut
 
 sub pm_to_blib {
-    my($fromto,$autodir,$pm_filter,$perm_dir) = @_;
+    my($fromto,$autodir,$pm_filter) = @_;
 
-    _mkpath($autodir,0,$perm_dir);
+    _mkpath($autodir,0,0755);
     while(my($from, $to) = each %$fromto) {
         if( -f $to && -s $from == -s $to && -M $to < -M $from ) {
             print "Skip $to (unchanged)\n" unless $INSTALL_QUIET;
@@ -1203,7 +1203,7 @@ sub pm_to_blib {
             # we wont try hard here. its too likely to mess things up.
             forceunlink($to);
         } else {
-            _mkpath(dirname($to),0,$perm_dir);
+            _mkpath(dirname($to),0,0755);
         }
         if ($need_filtering) {
             run_filter($pm_filter, $from, $to);
